Struct BootOptions
Source #[repr(C)]
pub struct BootOptions {Show 127 fields
pub aslr_disabled: bool,
pub aslr_entropy_bits: u8,
pub cprng_reseed_require_hw_rng: bool,
pub cprng_reseed_require_jitterentropy: bool,
pub cprng_seed_require_hw_rng: bool,
pub cprng_disable_jitterentropy: bool,
pub cprng_disable_hw_rng: bool,
pub cprng_seed_require_jitterentropy: bool,
pub cprng_seed_require_cmdline: bool,
pub entropy_mixin: RedactedHex,
pub jitterentropy_bs: u32,
pub jitterentropy_bc: u32,
pub jitterentropy_ml: u32,
pub jitterentropy_ll: u32,
pub jitterentropy_raw: bool,
pub jitterentropy_entropy_per_1000_bytes: u32,
pub lockup_detector_critical_section_threshold_ms: u64,
pub lockup_detector_critical_section_fatal_threshold_ms: u64,
pub lockup_detector_heartbeat_period_ms: u64,
pub lockup_detector_heartbeat_age_threshold_ms: u64,
pub lockup_detector_age_fatal_threshold_ms: u64,
pub lockup_detector_diagnostic_query_timeout_ms: u64,
pub oom_behavior: OomBehavior,
pub oom_timeout_ms: u32,
pub mexec_force_high_ramdisk: bool,
pub oom_enabled: bool,
pub oom_out_of_memory_threshold_mb: u64,
pub oom_critical_threshold_mb: u64,
pub oom_warning_threshold_mb: u64,
pub oom_debounce_mb: u64,
pub oom_evict_at_warning: bool,
pub oom_evict_continuous: bool,
pub oom_eviction_delay_ms: u64,
pub oom_evict_with_min_target: bool,
pub oom_eviction_delta_at_oom_mb: u64,
pub oom_hysteresis_seconds: u64,
pub oom_imminent_oom_delta_mb: u64,
pub oom_trigger_on_alloc_failure: bool,
pub phys_next: SmallString,
pub phys_verbose: bool,
pub phys_backtrace_max: u32,
pub phys_print_stack_max: u32,
pub ppb_borrow_on_mru: bool,
pub ppb_loan: bool,
pub ppb_replace_on_unloan: bool,
pub render_dlog_to_crashlog: bool,
pub serial: __BindgenOpaqueArray8<[u8; 24]>,
pub always_use_next_vdso: bool,
pub vdso_ticks_get_force_syscall: bool,
pub vdso_clock_get_force_syscall: bool,
pub userpager_overtime_wait_seconds: u64,
pub userpager_overtime_timeout_seconds: u64,
pub userpager_overtime_printout_limit: u32,
pub enable_virtual_heap: bool,
pub heap_max_size_mb: u64,
pub heap_alloc_fill_threshold: u64,
pub bufferchain_reserve_pages: u64,
pub bypass_debuglog: bool,
pub debug_uart_poll: bool,
pub enable_debugging_syscalls: bool,
pub enable_serial_syscalls: SerialDebugSyscalls,
pub entropy_test_src: EntropyTestSource,
pub entropy_test_len: u64,
pub force_watchdog_disabled: bool,
pub halt_on_panic: bool,
pub ktrace_bufsize: u32,
pub ktrace_grpmask: u32,
pub memory_limit_dbg: bool,
pub memory_limit_mb: u64,
pub page_scanner_enable_eviction: bool,
pub page_scanner_page_table_eviction_policy: PageTableEvictionPolicy,
pub page_scanner_page_table_eviction_period_ms: u32,
pub page_scanner_min_aging_interval_ms: u32,
pub page_scanner_max_aging_interval_ms: u32,
pub page_scanner_accessed_scan_interval_ms: u32,
pub page_scanner_active_ratio_multiplier: u32,
pub page_scanner_start_at_boot: bool,
pub page_scanner_zero_page_scans_per_second: u64,
pub lru_action: ScannerLruAction,
pub random_debug_compress: bool,
pub compression_strategy: CompressionStrategy,
pub compression_storage_strategy: CompressionStorageStrategy,
pub compression_threshold: u32,
pub compression_lz4_acceleration: u32,
pub compression_at_memory_pressure: bool,
pub compression_reclaim_anonymous: bool,
pub compression_reclaim_zero_forks: bool,
pub pmm_checker_action: CheckFailAction,
pub pmm_checker_enabled: CheckerEnable,
pub pmm_checker_fill_size: __BindgenOpaqueArray8<[u8; 16]>,
pub pmm_alloc_random_should_wait: bool,
pub stack_canary_percent_free: u64,
pub port_observer_reserve_pages: u64,
pub port_packet_reserve_pages: u64,
pub root_job_behavior: RootJobBehavior,
pub root_job_notice: SmallString,
pub shell: bool,
pub shell_script: SmallString,
pub smp_ht_enabled: bool,
pub test_ram_reserve: __BindgenOpaqueArray8<[u8; 32]>,
pub max_port_observers: u64,
pub select: SmallString,
pub userboot: SmallString,
pub scheduler_prefer_little_cpus: bool,
pub enable_new_wakeup_accounting: bool,
pub ubsan_action: CheckFailAction,
pub debug_boot_spin: bool,
pub allow_debug_uart_suspend: bool,
pub experimental_expand_memory_stall: bool,
pub x86_disable_spec_mitigations: bool,
pub x86_hwp: bool,
pub x86_hwp_policy: IntelHwpPolicy,
pub x86_md_clear_on_user_return: bool,
pub x86_spec_store_bypass_disable: bool,
pub x86_turbo: bool,
pub x86_enable_pcid: bool,
pub x86_smp_max_cpus: u32,
pub x86_wallclock: WallclockType,
pub test_uint32: u32,
pub test_uint64: u64,
pub test_bool: bool,
pub test_smallstring: SmallString,
pub test_enum: TestEnum,
pub test_struct: TestStruct,
pub test_redacted_hex: RedactedHex,
pub test_auto_or_uint64: __BindgenOpaqueArray8<[u8; 16]>,
pub smp_max_cpus: u32,
}
random_debug_compress: boolpmm_alloc_random_should_wait: boolexperimental_expand_memory_stall: bool
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.